@@ -276,7 +276,8 @@ static const char roles[] =
   "grouping\0"
   "image map\0"
   "notification\0"
-  "info bar\0";
+  "info bar\0"
+  "level bar\0";
 
 static const guint16 roles_offsets[] = {
   0, 8, 26, 32, 42, 48, 57, 64, 
@@ -291,7 +292,7 @@ static const guint16 roles_offsets[] = {
   751, 757, 769, 782, 791, 810, 816, 822, 
   830, 845, 853, 858, 866, 883, 888, 893,
   913, 923, 933, 954, 976, 990, 1003, 1018,
-  1026, 1035, 1044, 1054, 1067
+  1026, 1035, 1044, 1054, 1067, 1075
 };
 
 /* This is a static assertion */
@@ -545,7 +546,7 @@ atk_object_class_init (AtkObjectClass *klass)
                                                         _("The accessible role of this object"),
                                                         0,
                                                         G_MAXINT,
-                                                        0,
+                                                        ATK_ROLE_UNKNOWN,
                                                         G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_LAYER,
@@ -1400,24 +1401,10 @@ static AtkStateSet*
 atk_object_real_ref_state_set (AtkObject *accessible) 
 {
   AtkStateSet *state_set;
-  AtkObject *ap;
   AtkObject *focus_object;
 
   state_set = atk_state_set_new ();
 
-  ap = atk_object_get_parent (accessible);
-  if (ap)
-    if (ATK_IS_SELECTION (ap))
-      {
-        int i;
-
-        atk_state_set_add_state (state_set, ATK_STATE_SELECTABLE);
-
-        i = atk_object_get_index_in_parent (accessible);
-        if (i >= 0)
-          if (atk_selection_is_child_selected(ATK_SELECTION (ap), i))
-            atk_state_set_add_state (state_set, ATK_STATE_SELECTED);
-      } 
   focus_object = atk_get_focus_object ();
   if (focus_object == accessible)
     atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
@@ -1636,7 +1623,8 @@ atk_object_add_relationship (AtkObject       *object,
   g_return_val_if_fail (ATK_IS_OBJECT (object), FALSE);
   g_return_val_if_fail (ATK_IS_OBJECT (target), FALSE);
 
-  if (atk_relation_set_contains (object->relation_set, relationship))
+  if (atk_relation_set_contains_target (object->relation_set,
+                                        relationship, target))
     return FALSE;
 
   array[0] = target;
